-----------------------------------------------------------------------------------------------
-- Client Lua Script for GoldDollars
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
require "CREDDExchangeLib"
 
-----------------------------------------------------------------------------------------------
-- GoldDollars Module Definition
-----------------------------------------------------------------------------------------------
local GoldDollars = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function GoldDollars:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function GoldDollars:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- GoldDollars OnLoad
-----------------------------------------------------------------------------------------------
function GoldDollars:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("GoldDollars.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- GoldDollars OnDocLoaded
-----------------------------------------------------------------------------------------------
function GoldDollars:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "GoldDollarsForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("golddollars", "OnGoldDollarsOn", self)
		Apollo.RegisterEventHandler("CREDDExchangeInfoResults", 	"OnCREDDExchangeInfoResults", self)
		self.secondsTimer = ApolloTimer.Create(1.000, true, "OnSecondsTimer", self)
		self.hoursTimer = ApolloTimer.Create(3600.000, true, "OnHoursTimer", self)
		self.price = 0
		CREDDExchangeLib.RequestExchangeInfo()
		self.reset = false
		self.resetGold = 0
		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- GoldDollars Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/golddollars"
function GoldDollars:OnGoldDollarsOn()
	self.wndMain:Invoke() -- show the window
end

-- on seconds timer
function GoldDollars:OnSecondsTimer()
	-- Update values
	local temp = GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Credits)
	self.wndMain:FindChild("lblTotalEarnedValue"):SetText("$ " .. string.format("%.2f", temp:GetAmount()/self.price))
	if self.reset == true then
		local gained = temp:GetAmount() - self.resetGold
		self.wndMain:FindChild("lblSinceResetValue"):SetText("$ " .. string.format("%.2f", gained/self.price))
	end
end

-- on hours timer
function GoldDollars:OnHoursTimer()
	-- Get price of CREDD
	CREDDExchangeLib.RequestExchangeInfo()
end

function GoldDollars:OnCREDDExchangeInfoResults(arMarketStats, arOrders)
	local buyOrderData = arMarketStats.arBuyOrderPrices[1]
	local sellOrderData = arMarketStats.arSellOrderPrices[1]
	local average = (buyOrderData.monPrice:GetAmount() + sellOrderData.monPrice:GetAmount()) / 2
	self.price = average / 19.99
end

-----------------------------------------------------------------------------------------------
-- GoldDollarsForm Functions
-----------------------------------------------------------------------------------------------

--Convert button was clicked
function GoldDollars:btnConvert_Click( wndHandler, wndControl, eMouseButton )
	local plat = tonumber(self.wndMain:FindChild("tbPlat"):GetText())
	plat = plat * 100 * 100 * 100
	local gold = tonumber(self.wndMain:FindChild("tbGold"):GetText())
	gold = gold * 100 * 100
	local silver = tonumber(self.wndMain:FindChild("tbSilver"):GetText())
	silver = silver * 100
	local copper = tonumber(self.wndMain:FindChild("tbCopper"):GetText())
	local total = plat + gold + silver + copper
	self.wndMain:FindChild("lblUSD"):SetText("$ " .. string.format("%.2f", total/self.price))
end

function GoldDollars:OnCancel( wndHandler, wndControl, eMouseButton )
	self.wndMain:Close()
end

function GoldDollars:btnReset_Click( wndHandler, wndControl, eMouseButton )
	self.reset = true
	local temp = GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Credits)
	self.resetGold = temp:GetAmount()
end

-----------------------------------------------------------------------------------------------
-- GoldDollars Instance
-----------------------------------------------------------------------------------------------
local GoldDollarsInst = GoldDollars:new()
GoldDollarsInst:Init()
